#
# spec file for package J7Z
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1320 || 0%{?is_opensuse}
%bcond_without  kf5
%endif
Name:           J7Z
Version:        1.4.2
Release:        2.22
Summary:        Java-based P7Zip GUI for data compression and backup
License:        LGPL-3.0-or-later
Url:            http://j7z.xavion.name
Source:         https://downloads.sourceforge.net/project/k7z/J7Z%%20%%28All%%29/%{version}/J7Z-%{version}-src.tar.bz2
BuildRequires:  ImageMagick
BuildRequires:  ant >= 1.8.0
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  java-devel >= 1.8
BuildRequires:  p7zip
BuildRequires:  update-desktop-files
Requires:       java >= 1.8
Requires:       p7zip
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%if %{with kf5}
BuildRequires:  kf5-filesystem
%endif
%if 0%{?suse_version} > 1320
BuildRequires:  strip-nondeterminism
%endif

%description
J7Z is an alternative 7-Zip GUI. (7-Zip is a file archiver.)
With J7Z, you can update existing archive, backup multiple
directories to a storage location, create or extract protected
archives. It allows using archiving profiles and lists.

%if %{with kf5}
%package kf5
Summary:        KF5 service menu for J7Z
Requires:       J7Z

%description kf5
J7Z is an alternative 7-Zip GUI.
This package contains the KF5 service menu.
%endif

%prep
%setup -q -n J7Z
sed -i -e 's|Qt;KDE;Utility;Archiving;Compression|Qt;KDE;Utility;Archiving|g' \
	Linux/Desktop/Menu/J7Z.desktop

%build
pushd Linux/Build
make %{?_smp_mflags}
popd
%if 0%{?suse_version} > 1320
strip-nondeterminism `find -name \*.jar`
%endif

%install
pushd Linux/Build
make Install.AllUsers DESTDIR=%{buildroot}
popd

rm %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/J7Z.png
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/{48x48,64x64,128x128}/apps
for size in 32x32 48x48 64x64 128x128 ; do
  convert -strip -size 256x256 Source/Image/apps/J7Z.png -resize $size %{buildroot}%{_datadir}/icons/hicolor/$size/apps/J7Z.png
done

%if %{with kf5}
echo "X-SuSE-translate=true" >> %{buildroot}%{_kf5_servicesdir}/ServiceMenus/J7Z-Create.desktop
echo "X-SuSE-translate=true" >> %{buildroot}%{_kf5_servicesdir}/ServiceMenus/J7Z-Extract.desktop
rm -rf %{buildroot}%{_datadir}/kde4
%else
rm -rf %{buildroot}%{_datadir}/kde4
rm -rf %{buildroot}%{_datadir}/kservices5
%endif
echo "X-SuSE-translate=true" >> %{buildroot}%{_datadir}/J7Z/Desktop/KDE/J7Z-Create.desktop
echo "X-SuSE-translate=true" >> %{buildroot}%{_datadir}/J7Z/Desktop/KDE/J7Z-Extract.desktop
echo "X-SuSE-translate=true" >> %{buildroot}%{_datadir}/J7Z/Desktop/Menu/J7Z.desktop

%fdupes %{buildroot}/%{_prefix}

%files
%defattr(-,root,root)
%{_bindir}/J7Z.sh
%{_datadir}/J7Z/
%{_datadir}/applications/J7Z.desktop
%{_datadir}/icons/hicolor/16x16/actions/*.png
%{_datadir}/icons/hicolor/*/apps/J7Z.png

%if %{with kf5}
%files kf5
%defattr(-,root,root)
%dir %{_kf5_servicesdir}/ServiceMenus
%{_kf5_servicesdir}/ServiceMenus/*.desktop
%endif

%changelog
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Wed May  8 2019 enzokiel@kabelmail.de
- Update to version 1.4.2
  * Resolved the inability to work with Java >= v10
  * Improved the scalability of the GUI widgets
  * Upped the minimum required JRE to v1.8 (LTS)
- Removed J7Z-jdk10.patch, fixed upstream.
* Thu Apr 26 2018 enzokiel@kabelmail.de
- Fixed J7Z-jdk10.patch.
* Tue Mar 20 2018 enzokiel@kabelmail.de
- Update to version 1.4.1
  * Added initial support for JRE v9
  * Added icons for menu-bar entries
- Fixed J7Z-jdk10.patch.
- Removed all kde4 stuff from spec file.
* Fri Feb  2 2018 fstrba@suse.com
- Added patch:
  * J7Z-jdk10.patch
    + fix build with jdk10 preview or other jdk versions that
    have the optional string appended to its version.
* Tue May  2 2017 bwiedemann@suse.com
- Use strip-nondeterminism to not have timestamps in J7Z.jar file
- Use convert -strip to not have timestamps in png files
  to make build fully reproducible
* Sun Jan 29 2017 jengelh@inai.de
- Trim description to relevant parts
- Ensure fdupes is not run across partitions
* Thu Jan 19 2017 shshyukriev@suse.com
- Fix download url by using proper escaping via %%/.
* Mon Jan 16 2017 aloisio@gmx.com
- Update to version 1.4.0
  * Added support for KDE v5 and removed that for KDE v3
  * Installing Java updates in Windows no longer breaks J7Z
  * Improved the way that live skin switching is handled
  * Added support for the Insubstantial (Substance) skin
  * Theme changes are once again detected in the same session
  * Stopped some widgets from being enabled while archiving
  * The command-line usage is no longer shown in the GUI
  * Tidied Makefile output if some dependencies are missing
  * Stopped Makefile from calling 'uninstall' when packaging
  * Improved the update-checking and output-capturing code
- Spec cleanup
* Wed Mar  9 2016 joerg.lorenzen@ki.tng.de
- Update to version 1.3.0.svn20150830
  * Added support for kf5
* Fri Mar 13 2015 joerg.lorenzen@ki.tng.de
- Update to version 1.3.0.svn20150306:
  * Improved the way skin switching is handled
  * Added Insubstantial (Substance) skin support
* Tue Jan 27 2015 joerg.lorenzen@ki.tng.de
- Update to version 1.3.0:
  * Added Mac OS X support; installer plus Makefile
  * Now permitting skins to decorate window borders
  * Prevented the need to reinstall upon Java upgrade
  * Modernised code, increased required Java to v1.7
  * Added some new keyboard shortcuts & combinations
  * Prevented infinite loop when archiving many files
  * Reverted the default skin to the standard "Metal"
  * Changed the main application icon for distinction
  * Limited the MRU items lists to 20 historical rows
  * Made several minor changes to the code structure
* Sat Nov  9 2013 joerg.lorenzen@ki.tng.de
- Initial package, version 1.2.0.svn20130209
